using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using PhoenixDLL.Class.Managers;
using Utils.DataBase;
using PhoenixDLL.Class;
using System.Data.OleDb;
using Utils.Misc;
using PhoenixDLL.Print;

namespace PhoenixDLL.GUI
{
    /// <summary>
    /// Visionneuse de rendez-vous pour un patient
    /// </summary>
    public partial class fr_MeetingsViewer : Form
    {
        #region Variables
        /// <summary>
        /// Patient pour lequel on recherche les rendez-vous
        /// </summary>
        private PatientManager vPatientManager = new PatientManager();

        /// <summary>
        /// Gestionnaire de code SQL
        /// </summary>
        private OleDbSql SqlManager = new OleDbSql(Options.Instance.Path);

        /// <summary>
        /// Manager d'impression de rendez-vous
        /// </summary>
        private MeetingPrint vMeetingPrint = new MeetingPrint();

        /// <summary>
        /// Informations sur les rendez-vous
        /// </summary>
        private MeetingSet ms = new MeetingSet();
        #endregion

        #region Constructeur
        /// <summary>
        /// Constructeur
        /// </summary>
        public fr_MeetingsViewer()
        {
            InitializeComponent();
            lbl_Nom.Text = "";
            ppd.Document = vMeetingPrint.Document;
        }
        #endregion

        #region Accesseurs
        /// <summary>
        /// Retourne ou initialise le patient pour lequel on recherche les rendez-vous
        /// </summary>
        public PatientManager PatientManager
        {
            get { return vPatientManager; }
            set
            {
                //if (ms.MeetingList.Count < 1) return;

                vPatientManager = value;
                lbl_Nom.Text = value.ToString();

                ms = new MeetingSet();
                ms.Fill(vPatientManager.IDPatient);
                dgv_Results.Rows.Add(ms.MeetingList.Count);

                for (int i = 0; i < ms.MeetingList.Count; i++)
                {

                    dgv_Results.Rows[i].Cells[0].Value =
                        TextManager.FirstUpper(ms.MeetingList[i].StartDate.ToLongDateString())
                        + " de " + ms.MeetingList[i].StartDate.ToShortTimeString() + "  "
                        + ms.MeetingList[i].EndDate.ToShortTimeString(); ;
                }

                ms.Sort();
                vMeetingPrint.MeetingSet = ms;
                vMeetingPrint.PatientManager = vPatientManager;
                //dgv_Results.DataSource = ms;

            }
        }
        #endregion

        #region Events
        /// <summary>
        /// Quitter la fentre
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void MenuClick_Quit(object sender, EventArgs e) { this.Close(); }

        /// <summary>
        /// Demande d'impression du relev de rendez-vous
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void MenuClick_PrintPreview(object sender, EventArgs e)
        {
            ppd.ShowDialog();
        }

        /// <summary>
        /// Menu de configuration de l'imprimante
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void MenuClick_SetupPrinter(object sender, EventArgs e)
        {
            PrintDialog pd = new PrintDialog();
            DialogResult dr = pd.ShowDialog();
            if (dr != DialogResult.OK) return;
            
            vMeetingPrint.Document.PrinterSettings = pd.PrinterSettings;
        }
        #endregion
    }
}